@@ -96,7 +96,7 @@ FSX_PARAM_WITH_DEFAULT = {"drive_cache_type": "NONE", "data_compression_type": "
 
 EFA_UNSUPPORTED_ARCHITECTURES_OSES = {
     "x86_64": [],
-    "arm64": ["centos7", "centos8"],
+    "arm64": ["centos7"],
 }
 
 EBS_VOLUME_TYPE_TO_VOLUME_SIZE_BOUNDS = {
@@ -492,7 +492,7 @@ def efa_validator(param_key, param_value, pcluster_config):
         if cluster_section.get_param_value("placement_group") is None:
             warnings.append("You may see better performance using a cluster placement group.")
 
-    allowed_schedulers = ["sge", "slurm", "torque"]
+    allowed_schedulers = ["slurm"]
     if cluster_section.get_param_value("scheduler") not in allowed_schedulers:
         errors.append(
             "When using 'enable_efa = {0}' it is required to set the 'scheduler' parameter "
@@ -714,7 +714,12 @@ def url_validator(param_key, param_value, pcluster_config):
 
     else:
         try:
-            urllib.request.urlopen(param_value)  # nosec nosemgrep
+            match = re.match(r"https://(.*?)\.s3\.(.*?)amazonaws\.com(.*?)/(.*)", param_value)
+            if match and len(match.groups()) == 4:  # If S3 URL is provided.
+                bucket_name, object_name = match.group(1), match.group(4)
+                boto3.client("s3").head_object(Bucket=bucket_name, Key=object_name)
+            else:
+                urllib.request.urlopen(param_value)  # nosec nosemgrep
         except urllib.error.HTTPError as e:
             warnings.append("{0} {1} {2}".format(param_value, e.code, e.reason))
         except urllib.error.URLError as e:
@@ -964,14 +969,6 @@ def scheduler_validator(param_key, param_value, pcluster_config):
     if pcluster_config.get_section("cluster").get_param_value("base_os") not in supported_os:
         errors.append("'{0}' scheduler supports the following Operating Systems: {1}".format(param_value, supported_os))
 
-    will_be_deprecated = ["sge", "torque"]
-    wiki_url = "https://github.com/aws/aws-parallelcluster/wiki/Deprecation-of-SGE-and-Torque-in-ParallelCluster"
-    if param_value in will_be_deprecated:
-        warnings.append(
-            "The job scheduler you are using ({0}) is scheduled to be deprecated in future releases of "
-            "ParallelCluster. More information is available here: {1}".format(param_value, wiki_url)
-        )
-
     return errors, warnings
 
 
@@ -1092,7 +1089,7 @@ def intel_hpc_os_validator(param_key, param_value, pcluster_config):
     errors = []
     warnings = []
 
-    allowed_oses = ["centos7", "centos8"]
+    allowed_oses = ["centos7"]
 
     cluster_section = pcluster_config.get_section("cluster")
     if param_value and cluster_section.get_param_value("base_os") not in allowed_oses:
@@ -1147,11 +1144,6 @@ def architecture_os_validator(param_key, param_value, pcluster_config):
             "(M6g, C6g, etc.). To proceed please provide a custom_ami, "
             "for more info see: https://wiki.centos.org/Cloud/AWS#aarch64_notes"
         )
-    elif param_value == "centos8":
-        warnings.append(
-            f"Warning: The operating system you are using ({param_value}) will reach support end-of-life by the end "
-            "of 2021. It will not be included as part of future releases of ParallelCluster."
-        )
 
     return errors, warnings
 
